@@ -23,7 +23,7 @@ from alastria_service_client.validators import (
     Address,
 )
 from alastria_identity.types import JwtToken, AlastriaToken
-from network_service_client.client import AClient as ANetworkClient, CLient as NetworkClient, Network as NetworkDTO, NetworksNames
+from network_service_client.client import AClient as ANetworkClient, Client as NetworkClient, Network as NetworkDTO, NetworksNames
 
 
 class AlastriaAuthService(AAlastriaAuthService):
